@@ -4,7 +4,7 @@ use warnings;
 use Module::Pluggable::Object;
 use Test::More ();
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 my $USE_OK = sub {
     eval "use $_[0];"; ## no critic
@@ -14,6 +14,16 @@ my $USE_OK = sub {
     }
     return 1;
 };
+my $USE_NO_IMPORT_OK = sub {
+    eval "use $_[0] qw//;"; ## no critic
+    if (my $e = $@) {
+        Test::More::note($e);
+        return;
+    }
+    return 1;
+};
+
+
 my $REQUIRE_OK = sub {
     eval "require $_[0];"; ## no critic
     if (my $e = $@) {
@@ -47,6 +57,7 @@ sub all_ok {
     my $fork        = delete $param{fork};
     my $shuffle     = delete $param{shuffle};
     my $show_version = delete $param{show_version};
+    my $no_import   = delete $param{no_import};
 
     if ( _is_win() && $fork ) {
         Test::More::plan skip_all => 'The "fork" option is not supported in Windows';
@@ -54,7 +65,7 @@ sub all_ok {
     }
 
     my @checks;
-    push @checks, +{ test => $USE_OK,     name => 'use: '     } if $use_ok;
+    push @checks, +{ test => $no_import ? $USE_NO_IMPORT_OK : $USE_OK, name => 'use: ' } if $use_ok;
     push @checks, +{ test => $REQUIRE_OK, name => 'require: ' } if $require_ok;
 
     if (ref($check) eq 'CODE') {
@@ -197,32 +208,28 @@ Test::AllModules - do some tests for modules in search path
 
     use Test::AllModules;
 
-    BEGIN {
-        all_ok(
-            search_path => 'MyApp',
-            check => sub {
-                my $class = shift;
-                eval "use $class;1;";
-            },
-        );
-    }
+    all_ok(
+        search_path => 'MyApp',
+        use => 1,
+    );
 
-Here is also same as above: simplest one.
+
+Here is also same as above
 
     use Test::AllModules;
 
-    BEGIN {
-        all_ok(
-            search_path => 'MyApp',
-            use => 1,
-        );
-    }
-
+    all_ok(
+        search_path => 'MyApp',
+        check => sub {
+            my $class = shift;
+            eval "use $class;1;";
+        },
+    );
 
 
 =head1 DESCRIPTION
 
-Test::AllModules is do some tests for modules in search path.
+Test::AllModules is do some tests for all modules in search path.
 
 
 =head1 EXPORTED FUNCTIONS
@@ -249,14 +256,22 @@ If this option sets true value then do a load module(C<require>) test.
 
 This parameter is optional.
 
+=item * B<no_import> => boolean
+
+If this option sets true value then do not import any function when a test module is loaded.
+
+This parameter is optional.
+
 =item * B<check> => \&test_code_ref or hash( TEST_NAME => \&test_code_ref )
 
 =item * B<checks> => \@array: include hash( TEST_NAME => \&test_code_ref )
 
-The code to execute each module. The code receives C<$class> and C<$count>. The result from the code is passed to C<Test::More::ok()>.
+The code to execute each module. The code receives C<$class> and C<$count>. The result from the code will be passed to C<Test::More::ok()>. So, test codes must return true value if test is OK.
 
 =item * B<except> => \@array: include scalar or qr//
 
+Ignore modules.
+
 This parameter is optional.
 
 =item * B<lib> => \@array
@@ -271,7 +286,7 @@ If this option was set a value(1 or 2) then each check-code executes after forki
 
 This parameter is optional.
 
-NOTE that this option is NOT supported in Windows system.
+NOTE that this C<fork> option is NOT supported in Windows system.
 
 =item * B<shuffle> => boolean
 
@@ -281,7 +296,7 @@ This parameter is optional.
 
 =item * B<show_version> => boolean
 
-If this option was set the true value then the version of module will be shown.
+If this option was set the true value then the version of module will be shown if it's possible.
 
 This parameter is optional.
 
@@ -290,73 +305,48 @@ This parameter is optional.
 
 =head1 EXAMPLES
 
-if you need the name of test
+If you need the name of test, then you can use B<check> parameter: C<check => { test_name => sub { 'test' } }>
 
     use Test::AllModules;
 
-    BEGIN {
-        all_ok(
-            search_path => 'MyApp',
-            check => +{
-                'use_ok' => sub {
-                    my $class = shift;
-                    eval "use $class;1;";
-                },
-            },
-        );
-    }
-
-actually the count is also passed
-
-    use Test::AllModules;
-
-    BEGIN {
-        all_ok(
-            search_path => 'MyApp',
-            check => sub {
-                my ($class, $count) = @_;
+    all_ok(
+        search_path => 'MyApp',
+        check => +{
+            'use_ok' => sub {
+                my ($class, $test_count) = @_;
                 eval "use $class;1;";
             },
-        );
-    }
+        },
+    );
 
 more tests, all options
 
     use Test::AllModules;
 
-    BEGIN {
-        all_ok(
-
-            search_path => 'MyApp',
-
-            use => 1,
-
-            require => 1,
-
-            checks => [
-                +{
-                    'use_ok' => sub {
-                        my $class = shift;
-                        eval "use $class;1;";
-                    },
+    all_ok(
+        search_path => 'MyApp',
+        use     => 1,
+        require => 1,
+        checks  => [
+            +{
+                'use_ok' => sub {
+                    my $class = shift;
+                    eval "use $class; 1;";
                 },
-            ],
-
-            except => [
-                'MyApp::Role',
-                qr/MyApp::Exclude::.*/,
-            ],
-
-            lib => [
-                'lib',
-                't/lib',
-            ],
-
-            shuffle => 1,
-
-            fork => 1,
-        );
-    }
+            },
+        ],
+        except => [
+            'MyApp::Role',
+            qr/MyApp::Exclude::.*/,
+        ],
+        lib => [
+            'lib',
+            't/lib',
+        ],
+        shuffle   => 1,
+        fork      => 1,
+        no_import => 1,
+    );
 
 
 =head1 REPOSITORY
